@@ -1,4 +1,5 @@
-# -*- coding: latin-1 -*-
+﻿# -*- coding: utf-8 -*-
+
 
 """A Python implemntation of a kd-tree
 
@@ -13,8 +14,8 @@ import math
 from collections import deque
 from functools import wraps
 
-__author__ = 'Stefan Kögl <stefan@skoegl.net>'
-__version__ = '0.7'
+__author__ = u'Stefan Kögl <stefan@skoegl.net>'
+__version__ = '0.8'
 __website__ = 'https://github.com/stefankoegl/kdtree'
 __license__ = 'ISC license'
 
@@ -185,7 +186,11 @@ class Node(object):
             return self.data == other.data
 
     def __hash__(self):
-        return hash(self.data)
+        try:
+            return hash(self.data)
+        except TypeError:
+            # try to hash un-hashable types as tuples
+            return hash(tuple(self.data))
 
 
 def require_axis(f):
